==> ejc-analysis-impl-3.0.0-20230625.022018-29-sources.jar: com/ejianc/business/analysis/controller/ProfitIncomeController.java <==
package com.ejianc.business.analysis.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.analysis.bean.ProfitIncomeEntity;
import com.ejianc.business.analysis.mapper.ProfitIncomeMapper;
import com.ejianc.business.analysis.service.IProfitIncomeService;
import com.ejianc.business.analysis.vo.ProfitIncomeVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import net.sf.jxls.transformer.XLSTransformer;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.time.DateUtils;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.Serializable;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * 收入分析
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("profitIncome")
public class ProfitIncomeController implements Serializable {

	private static final long serialVersionUID = 1L;

    @Autowired
    private IOrgApi iOrgApi;

    @Autowired
    private IProfitIncomeService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ProfitIncomeVO> saveOrUpdate(@RequestBody ProfitIncomeVO saveOrUpdateVO) {
    	ProfitIncomeEntity entity = BeanMapper.map(saveOrUpdateVO, ProfitIncomeEntity.class);
    	service.saveOrUpdate(entity, false);
    	ProfitIncomeVO vo = BeanMapper.map(entity, ProfitIncomeVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ProfitIncomeVO> queryDetail(Long id) {
    	ProfitIncomeEntity entity = service.selectById(id);
    	ProfitIncomeVO vo = BeanMapper.map(entity, ProfitIncomeVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ProfitIncomeVO> vos) {
        service.removeByIds(vos.stream().map(ProfitIncomeVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ProfitIncomeVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 筛选栏：  项目,组织 */
        String searchText = null;
        String reportingMonth = null;
        List<Integer> projectStatus = new ArrayList<>();
        if(param.getParams().get("reportingMonth") != null){
            reportingMonth = param.getParams().get("reportingMonth").getValue().toString();
        }
        if(param.getParams().get("projectStatus") != null){
            String status = param.getParams().get("projectStatus").getValue().toString();
            String[] strs = status.split(",");
           for(String s : strs){
               projectStatus.add(Integer.parseInt(s));
           }

        }
        if(param.getSearchText() != null){
            searchText = param.getSearchText();
        }
        List<OrgVO> orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        List<Long> commonOrgIds = new ArrayList<>();
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Map<String, Object> paramMapper = new HashMap<>();
        paramMapper.put("tenantId", InvocationInfoProxy.getTenantid());
        paramMapper.put("commonOrgIds", commonOrgIds);
        paramMapper.put("departmentIds", departmentIds);
        paramMapper.put("projectStatus", projectStatus);
        paramMapper.put("searchText", searchText);
        paramMapper.put("reportingMonth", reportingMonth);//报表日期
        List<ProfitIncomeVO> profitIncomeVOList = service.queryListPage(paramMapper);


        List<ProfitIncomeVO> profitIncomeVOS = service.processingList(profitIncomeVOList);
        IPage<ProfitIncomeVO> page = new Page<>();
        page = new Page<>(page.getCurrent(), param.getPageSize(),profitIncomeVOS.size());
        page.setRecords(profitIncomeVOS);
        return CommonResponse.success("查询列表数据成功！",page);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 筛选栏：  项目,组织 */
        String searchText = null;
        String reportingMonth = null;
        List<Integer> projectStatus = new ArrayList<>();
        if(param.getParams().get("reportingMonth") != null){
            reportingMonth = param.getParams().get("reportingMonth").getValue().toString();
        }
        if(param.getParams().get("projectStatus") != null){
            String status = param.getParams().get("projectStatus").getValue().toString();
            String[] strs = status.split(",");
            for(String s : strs){
                projectStatus.add(Integer.parseInt(s));
            }

        }
        if(param.getSearchText() != null){
            searchText = param.getSearchText();
        }

        List<OrgVO> orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        List<Long> commonOrgIds = new ArrayList<>();
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            if(5 == org.getOrgType()) {
                //项目部
                departmentIds.add(org.getId());
            } else {
                //普通组织
                commonOrgIds.add(org.getId());
            }
        });

        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        Map<String, Object> paramMapper = new HashMap<>();
        paramMapper.put("tenantId", InvocationInfoProxy.getTenantid());
        paramMapper.put("commonOrgIds", commonOrgIds);
        paramMapper.put("departmentIds", departmentIds);
        paramMapper.put("projectStatus", projectStatus);
        paramMapper.put("searchText", searchText);
        paramMapper.put("reportingMonth", reportingMonth);//报表日期
        List<ProfitIncomeVO> profitIncomeVOList = service.queryListPage(paramMapper);
        List<ProfitIncomeVO> profitIncomeVOS = service.processingList(profitIncomeVOList);
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", profitIncomeVOS);

        XLSTransformer transformer = new XLSTransformer();
        ServletOutputStream outputStream = null;

        try {
            SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd");
            SimpleDateFormat timeFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
            beans.put("dateFormat", dateFormat);
            beans.put("timeFormat", timeFormat);
            ClassPathResource resource = new ClassPathResource("excel/ProfitIncome.xlsx" );
            outputStream = response.getOutputStream();
            Workbook workbook = transformer.transformXLS(resource.getInputStream(), beans);
            Sheet sheet = workbook.getSheetAt(0);
            sheet.getRow(0).getCell(0).setCellValue("截至"+ getdate(reportingMonth)+"项目收入分析");
            workbook.write(outputStream);
        } catch (Exception var18) {
            var18.printStackTrace();
        } finally {
            if (outputStream != null) {
                try {
                    outputStream.flush();
                    outputStream.close();
                } catch (IOException var17) {
                    var17.printStackTrace();
                }
            }
        }
    }
    public static String getdate(String date) {
        String[] datel = date.split(" ");
        String[] date2 = datel[0].split("-");
        String date4 = date2[0] + "年" + date2[1] + "月";
        return date4;
    }
    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refProfitIncomeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ProfitIncomeVO>> refProfitIncomeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ProfitIncomeEntity> page = service.queryPage(param,false);
        IPage<ProfitIncomeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ProfitIncomeVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     *
     * @return
     */
    @RequestMapping(value = "/execute", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> execute(HttpServletRequest request) {
        //定时任务设置天数，执行当前天数到上月当前天数
        String day = request.getParameter("day");
        //此日期方便手动调用接口数据
        String date = request.getParameter("date");
        service.execute(null,day,date,null);
        return CommonResponse.success("收入分析数据生成成功！");
    }

    /**
     *预生成本期数据
     * flag:1代表预生成按钮
     * @return
     */
    @RequestMapping(value = "/executeTest", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> executeTest(Integer inAdvanceFlag, @RequestParam(value = "day", required = false) String day, @RequestParam(value = "date") String date,@RequestParam(value = "projectIdList", required = false) List<Long> projectIdList) {
       /* //定时任务设置天数，执行当前天数到上月当前天数
        String day = request.getParameter("day");
        //此日期方便手动调用接口数据
        String date = request.getParameter("date");*/
        service.execute(inAdvanceFlag,day,date,projectIdList);
        return CommonResponse.success("收入分析数据生成成功！");
    }


}

==> ejc-analysis-impl-3.0.0-20230630.095827-36-sources.jar: com/ejianc/business/analysis/controller/ProfitIncomeController.java <==
package com.ejianc.business.analysis.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.analysis.bean.ProfitIncomeEntity;
import com.ejianc.business.analysis.bean.ProjectPaymentEntity;
import com.ejianc.business.analysis.service.IProfitIncomeService;
import com.ejianc.business.analysis.utils.CommonUtils;
import com.ejianc.business.analysis.vo.ProfitIncomeVO;
import com.ejianc.business.analysis.vo.ProjectPaymentVO;
import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ComputeUtil;
import net.sf.jxls.transformer.XLSTransformer;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.Serializable;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 收入分析
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("profitIncome")
public class ProfitIncomeController implements Serializable {

	private static final long serialVersionUID = 1L;


    @Autowired
    private IOrgApi iOrgApi;

    @Autowired
    private IProfitIncomeService service;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ProfitIncomeVO> saveOrUpdate(@RequestBody ProfitIncomeVO saveOrUpdateVO) {
    	ProfitIncomeEntity entity = BeanMapper.map(saveOrUpdateVO, ProfitIncomeEntity.class);
    	service.saveOrUpdate(entity, false);
    	ProfitIncomeVO vo = BeanMapper.map(entity, ProfitIncomeVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ProfitIncomeVO> queryDetail(Long id) {
    	ProfitIncomeEntity entity = service.selectById(id);
    	ProfitIncomeVO vo = BeanMapper.map(entity, ProfitIncomeVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ProfitIncomeVO> vos) {
        service.removeByIds(vos.stream().map(ProfitIncomeVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ProfitIncomeVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        IPage<ProfitIncomeEntity> page = service.queryPage(param,false);
        IPage<ProfitIncomeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        List<ProfitIncomeVO> projectPaymentVOList = BeanMapper.mapList(page.getRecords(), ProfitIncomeVO.class);
        List<ProfitIncomeVO> feeNewList = service.processingList(projectPaymentVOList);
        pageData.setRecords(feeNewList);
        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("projectName");
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        String reportingMonth = null;
        if(param.getParams().get("reportingMonth") != null){
            reportingMonth = param.getParams().get("reportingMonth").getValue().toString();
        }
        List<ProfitIncomeEntity> list = service.queryList(param);
        List<ProfitIncomeVO> feeNewList = service.processingList(BeanMapper.mapList(list, ProfitIncomeVO.class));
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", feeNewList);
        CommonUtils.setExcelName(response, reportingMonth,"项目收入分析","excel/ProfitIncome.xlsx", beans);

    }
    public static String getdate(String date) {
        String[] datel = date.split(" ");
        String[] date2 = datel[0].split("-");
        String date4 = date2[0] + "年" + date2[1] + "月";
        return date4;
    }
    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refProfitIncomeData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ProfitIncomeVO>> refProfitIncomeData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ProfitIncomeEntity> page = service.queryPage(param,false);
        IPage<ProfitIncomeVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ProfitIncomeVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     *
     * @return
     */
    @RequestMapping(value = "/execute", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> execute(HttpServletRequest request) {
        //定时任务设置天数，执行当前天数到上月当前天数
        String day = request.getParameter("day");
        service.execute(null,day,null);
        return CommonResponse.success("收入分析数据生成成功！");
    }

    /**
     *预生成本期数据
     * flag:1代表预生成按钮
     * @return
     */
    @RequestMapping(value = "/executeTest", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<String> executeTest( @RequestParam(value = "inAdvanceFlag", required = false)Integer inAdvanceFlag, @RequestParam(value = "day", required = false) String day,@RequestParam(value = "projectIdList", required = false) List<Long> projectIdList) {
        service.execute(inAdvanceFlag,day,projectIdList);
        return CommonResponse.success("收入分析数据生成成功！");
    }


}
